@@ -49,8 +49,6 @@ except Exception:
     EQT_VERSION = None
 
 def predictor(input_dir=None,
-              input_hdf5=None,
-              input_csv=None,
               input_model=None,
               output_dir=None,
               output_probabilities=False,
@@ -73,53 +71,103 @@ def predictor(input_dir=None,
               keepPS=True,
               spLimit=60): 
     
-    r"""
+    
+    """
     
     Applies a trained model to a windowed waveform to perform both detection and picking at the same time. 
 
-    Args:        
-        input_dir (str, optional): Directory name containing hdf5 and csv files-preprocessed data. Defaults to None. 
-        input_hdf5 (str, optional): Path to an hdf5 file containing only one class of "data" with NumPy arrays containing 3 component waveforms each 1 min long. Defaults to None.          
-        input_csv (str, optional): Path to a CSV file with one column (trace_name) listing the name of all datasets in the hdf5 file. Defaults to None.                  
-        input_model (str, optional): Path to a trained model. Defaults to None.           
-        output_dir (str, optional): Output directory. Defaults to None.   
-        output_probabilities (bool, optional): If True, it will output probabilities and estimated uncertainties for each trace into an HDF file. Defaults to False.              
-        detection_threshold (float, optional): A value in which the detection probabilities above it will be considered as an event. Defaults to 0.3.                
-        P_threshold (float, optional): A value which the P probabilities above it will be considered as P arrival. Defaults to 0.1.            
-        S_threshold (float, optional): A value which the S probabilities above it will be considered as S arrival. Defaults to 0.1.               
-        number_of_plots (int, optional): The number of plots for detected events outputed for each station data. Defaults to 10.        
-        plot_mode (str, optional): The type of plots: 'time': only time series or 'time_frequency': time and spectrograms. Defaults to 'time'.             
-        estimate_uncertainty (bool, optional): If True uncertainties in the output probabilities will be estimated. Defaults to False.             
-        number_of_sampling (int, optional): The number of Monte Carlo sampling to estimate the uncertainties. Defaults to 5.             
-        loss_weights (list, [optional): Loss weights for detection, P picking, and S picking respectively. Defaults to [0.03, 0.40, 0.58].               
-        loss_types (list, optional): Loss types for detection, P picking, and S picking respectively. Defaults to ['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy']        
-        input_dimention (int, optional): Loss types for detection, P picking, and S picking respectively. Defaults to (6000, 3).        
-        normalization_mode (str, optional): Mode of normalization for data preprocessing, 'max': maximum amplitude among three components, 'std': standard deviation. Defaults to 'std'           
-        batch_size: (int, optional): Batch size. Defaults to 500.           
-        gpuid (int, optional): Id of GPU used for the prediction. If using CPU set to None. Defaults to None.           
-        gpu_limit (tuple, optional): Set the maximum percentage of memory usage for the GPU. Defaults to None.
-        number_of_cpus (int, optional): Number of CPUs used for the parallel preprocessing and feeding of data for prediction. Defaults to 5.
-        use_multiprocessing (bool, optional): If True, multiple CPUs will be used for the preprocessing of data even when GPU is used for the prediction. Defaults to True.
-        keepPS (bool, optional): If True, only detected events that have both P and S picks will be written otherwise those events with either P or S pick. Defaults to False.
-        spLimit (int, optional): S - P time in seconds. It will limit the results to those detections with events that have a specific S-P time limit. Defaults to 60.
 
+    Parameters
+    ----------
+    input_dir: str, default=None
+        Directory name containing hdf5 and csv files-preprocessed data.
+        
+    input_model: str, default=None
+        Path to a trained model.
 
-    Returns:
-        ./output_dir/STATION_OUTPUT/X_prediction_results.csv: A table containing all the detection, and picking results. Duplicated events are already removed.      
-        ./output_dir/STATION_OUTPUT/X_report.txt: A summary of the parameters used for prediction and performance.
-        ./output_dir/STATION_OUTPUT/figures: A folder containing plots detected events and picked arrival times. 
-        ./output_dir/STATION_OUTPUT/output_probabilities.hdf5: An hdf5 containing the predicted probabilities for all samples. 
+    output_dir: str, default=None
+        Output directory that will be generated. 
+        
+    output_probabilities: bool, default=False
+        If True, it will output probabilities and estimated uncertainties for each trace into an HDF file.       
+         
+    detection_threshold : float, default=0.3
+        A value in which the detection probabilities above it will be considered as an event.
+          
+    P_threshold: float, default=0.1
+        A value which the P probabilities above it will be considered as P arrival.
 
-    Notes:
-        Estimating the uncertainties requires multiple predictions and will increase the computational time. 
+    S_threshold: float, default=0.1
+        A value which the S probabilities above it will be considered as S arrival.
+               
+    number_of_plots: float, default=10
+        The number of plots for detected events outputed for each station data.
+
+    plot_mode: str, default='time'
+        The type of plots: 'time': only time series or 'time_frequency', time and spectrograms.
+          
+    estimate_uncertainty: bool, default=False
+        If True uncertainties in the output probabilities will be estimated.           
+
+    number_of_sampling: int, default=5
+        Number of sampling for the uncertainty estimation. 
+               
+    loss_weights: list, default=[0.03, 0.40, 0.58]
+        Loss weights for detection, P picking, and S picking respectively.
+             
+    loss_types: list, default=['binary_crossentropy', 'binary_crossentropy', 'binary_crossentropy'] 
+        Loss types for detection, P picking, and S picking respectively.
+
+    input_dimention: tuple, default=(6000, 3)
+        Loss types for detection, P picking, and S picking respectively.      
+
+    normalization_mode: str, default='std' 
+        Mode of normalization for data preprocessing, 'max', maximum amplitude among three components, 'std', standard deviation.
+           
+    batch_size: int, default=500 
+        Batch size. This wont affect the speed much but can affect the performance. A value beteen 200 to 1000 is recommanded.
+
+    gpuid: int, default=None
+        Id of GPU used for the prediction. If using CPU set to None.
+         
+    gpu_limit: int, default=None
+        Set the maximum percentage of memory usage for the GPU.
+          
+    number_of_cpus: int, default=5
+        Number of CPUs used for the parallel preprocessing and feeding of data for prediction.
+
+    use_multiprocessing: bool, default=True
+        If True, multiple CPUs will be used for the preprocessing of data even when GPU is used for the prediction.        
+
+    keepPS: bool, default=False
+        If True, only detected events that have both P and S picks will be written otherwise those events with either P or S pick. 
+        
+    spLimit: int, default=60
+        S - P time in seconds. It will limit the results to those detections with events that have a specific S-P time limit. 
+        
+    Returns
+    -------- 
+    ./output_dir/STATION_OUTPUT/X_prediction_results.csv: A table containing all the detection, and picking results. Duplicated events are already removed.      
+    
+    ./output_dir/STATION_OUTPUT/X_report.txt: A summary of the parameters used for prediction and performance.
+    
+    ./output_dir/STATION_OUTPUT/figures: A folder containing plots detected events and picked arrival times. 
+    
+    ./time_tracks.pkl: A file containing the time track of the continous data and its type.
+    
+
+    Notes
+    --------
+    Estimating the uncertainties requires multiple predictions and will increase the computational time. 
+    
         
     """ 
    
     
     args = {
     "input_dir": input_dir,
-    "input_hdf5": input_hdf5,
-    "input_csv": input_csv,
+    "input_hdf5": None,
+    "input_csv": None,
     "input_model": input_model,
     "output_dir": output_dir,
     "output_probabilities": output_probabilities,
