@@ -31,33 +31,38 @@ import faulthandler; faulthandler.enable()
 
 
 def preprocessor(mseed_dir, stations_json, overlap=0.3, n_processor=None):
-  
+    
+    
     """
+    
     Performs preprocessing and partitions the continuous waveforms into 1-minute slices. 
 
     Parameters
     ----------
-       mseed_dir: str
-           Path to the directory containing mseed files (within folders for each station).
-       stations_json: str
-           Path to a dictionary containing the station's information.
-       overlap: float, (default = 0.3)
-           Percentage of overlapping of windows.
-       n_processor : int
-           The number of CPU processors for parallel downloading.
-                      
-    Generates
-    -------
-    ./mseed_dir_processed_hdfs/station.csv
-        A table containing trace names.
-    ./mseed_dir_processed_hdfs/station.hdf5
-        Containes all slices and preprocessed traces.        
-    ./X_preprocessor_report.txt
-        A summary of processing performance.
-    ./time_tracks.pkl
-        Contain the time track of the continous data and its type.
+    mseed_dir: str
+        A table containing trace names. 
+
+    stations_json: str
+        Path to a JSON file containing station information.        
         
+    overlap: float, default=0.3
+        If set, detection, and picking are performed in overlapping windows.
+           
+    n_processor: int, default=None 
+        The number of CPU processors for parallel downloading.         
+
+    Returns
+    ----------
+    mseed_dir_processed_hdfs/station.csv: Phase information for the associated events in hypoInverse format. 
+    
+    mseed_dir_processed_hdfs/station.hdf5: Containes all slices and preprocessed traces. 
+    
+    X_preprocessor_report.txt: A summary of processing performance. 
+    
+    time_tracks.pkl: Contain the time track of the continous data and its type.
+       
     """  
+ 
     
     if not n_processor:
         n_processor = multiprocessing.cpu_count()
